import { COOKIE_NAME_PRERENDER_BYPASS, checkIsOnDemandRevalidate } from "../api-utils";
export class DraftMode {
    constructor(previewProps, req, cookies, mutableCookies){
        var _this_cookies_get;
        this.cookies = cookies;
        this.mutableCookies = mutableCookies;
        // The logic for draftMode() is very similar to tryGetPreviewData()
        // but Draft Mode does not have any data associated with it.
        const isOnDemandRevalidate = previewProps && checkIsOnDemandRevalidate(req, previewProps).isOnDemandRevalidate;
        const cookieValue = (_this_cookies_get = this.cookies.get(COOKIE_NAME_PRERENDER_BYPASS)) == null ? void 0 : _this_cookies_get.value;
        this.enabled = Boolean(!isOnDemandRevalidate && cookieValue && previewProps && cookieValue === previewProps.previewModeId);
        this.previewModeId = previewProps == null ? void 0 : previewProps.previewModeId;
    }
    enable() {
        if (!this.previewModeId) {
            throw new Error("Invariant: previewProps missing previewModeId this should not be hit");
        }
        this.mutableCookies.set({
            name: COOKIE_NAME_PRERENDER_BYPASS,
            value: this.previewModeId,
            httpOnly: true,
            sameSite: process.env.NODE_ENV !== "development" ? "none" : "lax",
            secure: process.env.NODE_ENV !== "development",
            path: "/"
        });
    }
    disable() {
        // To delete a cookie, set `expires` to a date in the past:
        // https://tools.ietf.org/html/rfc6265#section-4.1.1
        // `Max-Age: 0` is not valid, thus ignored, and the cookie is persisted.
        this.mutableCookies.set({
            name: COOKIE_NAME_PRERENDER_BYPASS,
            value: "",
            httpOnly: true,
            sameSite: process.env.NODE_ENV !== "development" ? "none" : "lax",
            secure: process.env.NODE_ENV !== "development",
            path: "/",
            expires: new Date(0)
        });
    }
}

//# sourceMappingURL=draft-mode.js.map